@@ -13,6 +13,7 @@ import torchvision.transforms.functional as t_f
 from mmcv.utils import Config
 
 from easycv.file import io
+from easycv.framework.errors import ValueError
 from easycv.models import (DINO, MOCO, SWAV, YOLOX, Classification, MoBY,
                            build_model)
 from easycv.utils.checkpoint import load_checkpoint
@@ -106,6 +107,9 @@ def _export_cls(model, cfg, filename):
         backbone=replace_syncbn(cfg.model.backbone),
     )
 
+    # avoid load pretrained model
+    model_config['pretrained'] = False
+
     if export_neck:
         if hasattr(cfg.model, 'neck'):
             model_config['neck'] = cfg.model.neck
@@ -168,10 +172,12 @@ def _export_yolox(model, cfg, filename):
         default_export_type_list = ['raw', 'jit', 'blade']
         if export_type not in default_export_type_list:
             logging.warning(
-                'YOLOX-PAI only supports the export type as  [raw,jit,blade], otherwise we use ori as default'
+                'YOLOX-PAI only supports the export type as  [raw,jit,blade], otherwise we use raw as default'
             )
             export_type = 'raw'
 
+        model.export_type = export_type
+
         if export_type != 'raw':
             # only when we use jit or blade, we need to reparameterize_models before export
             model = reparameterize_models(model)
@@ -199,7 +205,7 @@ def _export_yolox(model, cfg, filename):
                     use_trt_efficientnms == False
                 ), 'Export YoloX predictor use_trt_efficientnms=True only when use static_opt=True!'
 
-            # preprocess can not be optimized blade, to accelerate the inference, a preprocess jit model should be saved!
+            # allow to save a preprocess jit model with exported model
             save_preprocess_jit = False
 
             if preprocess_jit:
@@ -607,8 +613,17 @@ class ModelExportWrapper(torch.nn.Module):
         self.example_inputs = example_inputs
 
         self.trace_model = trace_model
+
         if self.trace_model:
-            self.trace_module()
+            try:
+                self.trace_module()
+            except RuntimeError:
+                # well trained model will generate reasonable result, otherwise, we should change model.test_conf=0.0 to avoid tensor in inference to be empty
+                logging.warning(
+                    'PAI-YOLOX: set model.test_conf=0.0 to avoid tensor in inference to be empty'
+                )
+                model.test_conf = 0.0
+                self.trace_module()
 
     def trace_module(self, **kwargs):
         trace_model = torch.jit.trace_module(
