@@ -13,6 +13,7 @@ from torchvision.transforms import functional as F
 
 from easycv.datasets.registry import PIPELINES
 from easycv.datasets.shared.pipelines.transforms import Compose
+from easycv.framework.errors import KeyError, NotImplementedError, TypeError
 
 try:
     from panopticapi.utils import rgb2id
@@ -1122,8 +1123,8 @@ class MMRandomFlip:
         elif flip_ratio is None:
             pass
         else:
-            raise ValueError('flip_ratios must be None, float, '
-                             'or list of float')
+            raise TypeError('flip_ratios must be None, float, '
+                            'or list of float')
         self.flip_ratio = flip_ratio
 
         valid_directions = ['horizontal', 'vertical', 'diagonal']
@@ -1133,7 +1134,7 @@ class MMRandomFlip:
             assert mmcv.is_list_of(direction, str)
             assert set(direction).issubset(set(valid_directions))
         else:
-            raise ValueError('direction must be either str or list of str')
+            raise TypeError('direction must be either str or list of str')
         self.direction = direction
 
         if isinstance(flip_ratio, list):
@@ -1168,7 +1169,7 @@ class MMRandomFlip:
             flipped[..., 2::4] = w - bboxes[..., 0::4]
             flipped[..., 3::4] = h - bboxes[..., 1::4]
         else:
-            raise ValueError(f"Invalid flipping direction '{direction}'")
+            raise KeyError(f"Invalid flipping direction '{direction}'")
         return flipped
 
     def __call__(self, results):
@@ -1274,7 +1275,7 @@ class MMRandomCrop:
         if crop_type not in [
                 'relative_range', 'relative', 'absolute', 'absolute_range'
         ]:
-            raise ValueError(f'Invalid crop_type {crop_type}.')
+            raise KeyError(f'Invalid crop_type {crop_type}.')
         if crop_type in ['absolute', 'absolute_range']:
             assert crop_size[0] > 0 and crop_size[1] > 0
             assert isinstance(crop_size[0], int) and isinstance(
@@ -1902,7 +1903,7 @@ class LoadAnnotations:
         repr_str += f'with_seg={self.with_seg}, '
         repr_str += f'poly2mask={self.poly2mask}, '
         repr_str += f'poly2mask={self.file_client_args})'
-        return
+        return repr_str
 
 
 @PIPELINES.register_module()
