@@ -3,8 +3,11 @@ from .backbones import *  # noqa: F401,F403
 from .builder import build_backbone, build_head, build_loss, build_model
 from .classification import *
 from .detection import *
+from .detection3d import *
+from .face import *
 from .heads import *
 from .loss import *
+from .ocr import *
 from .pose import TopDown
 from .registry import BACKBONES, HEADS, LOSSES, MODELS, NECKS
 from .segmentation import *
