@@ -15,6 +15,7 @@ from typing import Optional
 import torch
 from torch import Tensor, nn
 
+from easycv.framework.errors import NotImplementedError
 from easycv.models.builder import NECKS
 from easycv.models.detection.utils import (gen_encoder_output_proposals,
                                            gen_sineembed_for_position,
@@ -249,7 +250,7 @@ class DeformableTransformer(nn.Module):
             if p.dim() > 1:
                 nn.init.xavier_uniform_(p)
         for m in self.modules():
-            from thirdparty.deformable_attention.modules import MSDeformAttn
+            from easycv.thirdparty.deformable_attention.modules import MSDeformAttn
             if isinstance(m, MSDeformAttn):
                 m._reset_parameters()
         if self.num_feature_levels > 1 and self.level_embed is not None:
@@ -908,7 +909,7 @@ class DeformableTransformerEncoderLayer(nn.Module):
         super().__init__()
 
         # self attention
-        from thirdparty.deformable_attention.modules import MSDeformAttn
+        from easycv.thirdparty.deformable_attention.modules import MSDeformAttn
         self.self_attn = MSDeformAttn(
             d_model, n_levels, n_heads, n_points, im2col_step=64)
         self.dropout1 = nn.Dropout(dropout)
@@ -982,7 +983,7 @@ class DeformableTransformerDecoderLayer(nn.Module):
         assert sorted(module_seq) == ['ca', 'ffn', 'sa']
 
         # cross attention
-        from thirdparty.deformable_attention.modules import MSDeformAttn
+        from easycv.thirdparty.deformable_attention.modules import MSDeformAttn
         self.cross_attn = MSDeformAttn(
             d_model, n_levels, n_heads, n_points, im2col_step=64)
         self.dropout1 = nn.Dropout(dropout)
@@ -1008,7 +1009,7 @@ class DeformableTransformerDecoderLayer(nn.Module):
         assert decoder_sa_type in ['sa', 'ca_label', 'ca_content']
 
         if decoder_sa_type == 'ca_content':
-            from thirdparty.deformable_attention.modules import MSDeformAttn
+            from easycv.thirdparty.deformable_attention.modules import MSDeformAttn
             self.self_attn = MSDeformAttn(
                 d_model, n_levels, n_heads, n_points, im2col_step=64)
 
