@@ -4,7 +4,7 @@ from .boxes import (batched_nms, bbox2result, bbox_overlaps, bboxes_iou,
                     box_cxcywh_to_xyxy, box_xyxy_to_cxcywh, distance2bbox,
                     fp16_clamp, generalized_box_iou)
 from .generator import MlvlPointGenerator
-from .misc import (accuracy, filter_scores_and_topk,
-                   gen_encoder_output_proposals, gen_sineembed_for_position,
-                   interpolate, inverse_sigmoid, select_single_mlvl)
+from .misc import (accuracy, gen_encoder_output_proposals,
+                   gen_sineembed_for_position, interpolate, inverse_sigmoid,
+                   select_single_mlvl)
 from .postprocess import DetrPostProcess, output_postprocess, postprocess
