@@ -1,12 +1,11 @@
 # Copyright (c) Alibaba, Inc. and its affiliates.
+import functools
+import inspect
 import logging
-from functools import partial
+import warnings
 
 import mmcv
 import numpy as np
-from six.moves import map, zip
-
-from easycv.models.backbones.repvgg_yolox_backbone import RepVGGBlock
 
 
 def tensor2imgs(tensor, mean=(0, 0, 0), std=(1, 1, 1), to_rgb=True):
@@ -22,25 +21,6 @@ def tensor2imgs(tensor, mean=(0, 0, 0), std=(1, 1, 1), to_rgb=True):
     return imgs
 
 
-def multi_apply(func, *args, **kwargs):
-    """Apply function to a list of arguments.
-    Note:
-        This function applies the ``func`` to multiple inputs and
-        map the multiple outputs of the ``func`` into different
-        list. Each list contains the same type of outputs corresponding
-        to different inputs.
-    Args:
-        func (Function): A function that will be applied to a list of
-            arguments
-    Returns:
-        tuple(list): A tuple containing multiple list, each list contains \
-            a kind of returned results by the function
-    """
-    pfunc = partial(func, **kwargs) if kwargs else func
-    map_results = map(pfunc, *args)
-    return tuple(map(list, zip(*map_results)))
-
-
 def unmap(data, count, inds, fill=0):
     """ Unmap a subset of item (data) back to the original set of items (of
     size count) """
@@ -79,6 +59,8 @@ def reparameterize_models(model):
     Args:
         model: nn.Module
     """
+    from easycv.models.backbones.repvgg_yolox_backbone import RepVGGBlock
+
     reparameterize_count = 0
     for layer in model.modules():
         if isinstance(layer, RepVGGBlock):
@@ -89,3 +71,31 @@ def reparameterize_models(model):
         .format(reparameterize_count))
     print('reparam:', reparameterize_count)
     return model
+
+
+def deprecated(reason):
+    """
+    This is a decorator which can be used to mark functions
+    as deprecated. It will result in a warning being emitted
+    when the function is used.
+    """
+
+    def decorator(func1):
+        if inspect.isclass(func1):
+            fmt1 = 'Call to deprecated class {name} ({reason}).'
+        else:
+            fmt1 = 'Call to deprecated function {name} ({reason}).'
+
+        @functools.wraps(func1)
+        def new_func1(*args, **kwargs):
+            warnings.simplefilter('always', DeprecationWarning)
+            warnings.warn(
+                fmt1.format(name=func1.__name__, reason=reason),
+                category=DeprecationWarning,
+                stacklevel=2)
+            warnings.simplefilter('default', DeprecationWarning)
+            return func1(*args, **kwargs)
+
+        return new_func1
+
+    return decorator
